/**
 * perseus/connector: this is an implementation of some JCA-related technologies
 * (resource adapters and managers) for the ObjectWeb consortium.
 * Copyright (C) 2001-2002 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: pascal.dechamboux@rd.francetelecom.com
 *
 */

package org.objectweb.perseus.connector.manager.standalone;

import javax.resource.ResourceException;
import javax.resource.spi.ConnectionManager;
import javax.resource.spi.ConnectionRequestInfo;
import javax.resource.spi.ManagedConnection;
import javax.resource.spi.ManagedConnectionFactory;

/**
 * @author	P. Dechamboux
 */
public class SaManager
	implements ConnectionManager, SaManagerAttributeControler {
	/**
	 * The ManagedConnectionFactory used by this ConnectionManager to
	 * create ManagedConnection.
	 */
	ManagedConnectionFactory managedConnectionFactory = null;

	// IMPLEMENTATION OF METHODS FROM THE ConnectionManager INTERFACE

	/**
	 * Always creates a new ManagedConnection from the associated
	 * ManagedConnectionFactory.
	 */
	public Object allocateConnection(
		ManagedConnectionFactory factory,
		ConnectionRequestInfo info)
		throws ResourceException {
		if (managedConnectionFactory == null)
			managedConnectionFactory = factory;
		else if (managedConnectionFactory != factory)
			throw new ResourceException("SAM: should always use the same ManagedConnectionFactory.");
		//matchManagedConnections(connset, /*Subject*/null, info);
		ManagedConnection mc
			= managedConnectionFactory.createManagedConnection(/*Subject*/null, info);
		Object res = mc.getConnection(/*Subject*/null, info);
		mc.associateConnection(res);
		return res;
	}

	// IMPLEMENTATION OF METHODS FROM THE SaManagerAttributeControler INTERFACE

	/**
	 * Gives access to the ManagedConnectionFactory associated with this
	 * ConnectionManager.
	 */
	public ManagedConnectionFactory getManagedConnectionFactory() {
		return managedConnectionFactory;
	}

	/**
	 * Changes the ManagedConnectionFactory associated with this
	 * ConnectionManager. If the ConnectionManager is already active (it has
	 * been started), it has no effect (new ManagedConnectionFactory not
	 * assigned).
	 * @param mcf	The new ManagedConnectionFactory.
	 */
	public void setManagedConnectionFactory(ManagedConnectionFactory mcf) {
		managedConnectionFactory = mcf;
	}
}