/**
 * Copyright (C) 2000
 */

package org.objectweb.perseus.fos.api;

import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.MonologFactory;

/**
 * Defines the way to retrieve the logger associated to the different kinds of
 * FOS entities that are traced.
 * @author	S. Chassande-Barrioz, P. D�chamboux
 */
public interface FosLoggerFactory {
	/**
	 * For removing all DEBUG traces from the FOS adapter code,
	 * set it to false!!
	 */
	final static boolean DEBUG = true;
	/**
	 * For Connection entities associated to the FOS.
	 */
	final static byte CONNECTION = 1;
	/**
	 * For ManagedConnection entities associated to the FOS.
	 */
	final static byte MANAGEDCONNECTION = 2;
	/**
	 * For XAResource entities associated to the FOS.
	 */
	final static byte XARESOURCE = 4;
	/**
	 * For TxContext entities associated to the FOS.
	 */
	final static byte TXCONTEXT = 8;

	/**
	 * Gives access to the logger associated to a given kind of entities managed
	 * by this FOS adapter, which are further classified into factories or
	 * non-factories.
	 * @param entity	The kind of entity (see CONNECTION, MANAGEDCONNECTION,
	 * 					XARESOURCE and TXCONTEXT constants defined above).
	 * @param factory	Specifies if the concerned entity is a factory.
	 * @return	The relevant logger.
	 */
	Logger getLogger(byte entity, boolean factory);

	void setMonologFactory(MonologFactory mf);
}