/**
 * Copyright (C) 2000
 */

package org.objectweb.perseus.fos.api;

import javax.transaction.xa.Xid;

/**
 * Defines the means to manipulate FOS transaction and the FOS repository.
 * @author	S. Chassande-Barrioz, P. Dchamboux
 */
public interface FosManager extends FosAttributeControler, FosLoggerFactory {
	static final String SPECVERSION = "1.01";

	void start() throws FosException;

	void stop() throws FosException;

	/**
	 * Initializes the root directory for storing files representing data
	 * objects. It removes all existing data files and creates all data for
	 * managing transactions. It must be performed before starting the FOS.
	 */
	void initialize() throws FosException;

	/**
	 * Gets all the Xid of distributed transaction that need to be recovered
	 * by a DTP monitor. This method can only be called once (recoverable XID
	 * are lost upon new calls).
	 * @return	The array of Xid of transactions that need to be recovered.
	 */
	Xid[] getXidForRecovery();

	/**
	 * Creates a new FosTransaction for managing transactional I/Os with Data
	 * Object Files.
	 */
	FosTransaction createTxContext() throws FosException;

	/**
	 * Releases a FosTransaction. Useful if adding a transaction pool.
	 * @param txc	The FosTransaction to be released.
	 */
	void releaseTxContext(FosTransaction txc) throws FosException;
}
