/**
 * Copyright (C) 2000
 */

package org.objectweb.perseus.fos.api;

import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

/**
 * Defines the object for reading/writing the content of a persistent object
 * from/to its associated file within the File Object Store. This interface is
 * implemented by the FOS user that must provide it in order to define the exact
 * storage structure of stored objects.
 * @author	S. Chassande-Barrioz, P. Dchamboux
 */
public interface FosStructure {
	/**
	 * Reads the content of a persistent object from the file represented by
	 * the given ObjectInputStream.
	 * @param ois	The ObjectInputStream representing the file from which to
	 *				read.
	 * @param conn	The connection used to access the File Object Store.
	 */
	void readFile(ObjectInputStream ois, FosAccess conn, Object ctxt) throws Exception;

	/**
	 * Writes the content of a persistent object to the file represented by
	 * the given ObjectOutputStream.
	 * @param oos	The ObjectOutputStream representing the file to which to
	 *				write.
	 * @param conn	The connection used to access the File Object Store.
	 */
	void writeFile(ObjectOutputStream oos, FosAccess conn, Object ctxt) throws Exception;
}
