/**
 * Copyright (C) 2000
 */

package org.objectweb.perseus.fos.api;

import javax.transaction.xa.Xid;

/**
 * Defines the means to operate FOS transactions.
 * @author	S. Chassande-Barrioz, P. Dchamboux
 */
public interface FosTransaction extends FosAccess {
	/**
	 * Begins a FOS transaction with no DTP context.
	 */
	void begin() throws FosException;

	/**
	 * Begins a FOS transaction with a DTP context.
	 * @param xid	The DTP identifier associated with this FOS transaction. It
	 * 				is null if non XA runtime environment.
	 */
	void begin(Xid xid) throws FosException;

	/**
	 * Specifies if this FOS transaction is active or not. true means that
	 * it has begun but it has not been committed or rollbacked yet.
	 */
	boolean isActive();

	/**
	 * Prepares a FOS transaction for commit.
	 * @return	true if all objects used by this transaction was just read.
	 */
	boolean prepare() throws FosException;

	/**
	 * Commits a FOS transaction.
	 */
	void commit() throws FosException;

	/**
	 * Roolbacks a FOS transaction.
	 */
	void rollback() throws FosException;
}