/**
 * Copyright (C) 2000
 */

package org.objectweb.perseus.fos.lib;

import org.objectweb.perseus.fos.api.FosException;

import java.io.File;
import java.io.FilenameFilter;
import java.util.Iterator;
import java.util.NoSuchElementException;

/**
 * Defines the way to iterate over the Object Files within a directory.
 * @author	S. Chassande-Barrioz, P. Dchamboux
 */
public class FosExtension implements Iterator, FilenameFilter {
	private String[] fnList;
	private int next = 0;

	private FosExtension() {
	}

	/**
	 * Constructs a Data Object Files extension iterator.
	 * @param dn	The name of the Data Object Files directory.
	 */
	FosExtension(String dn) throws FosException {
		File fod = new File(dn);
		if (!fod.exists())
			fnList = null;
		else if (!fod.isDirectory()) {
			fnList = null;
			throw new FosException("Wrong directory name: " + dn);
		}
		fnList = fod.list(this);
	}

	/**
	 * Tests if there are more elements to tranverse.
	 */
	public boolean hasNext() {
		if (fnList == null)
			return false;
		return next < fnList.length;
	}

	/**
	 * Traverses the next element.
	 */
	public Object next() throws NoSuchElementException {
		if (next >= fnList.length)
			throw new NoSuchElementException();
		return fnList[next++];
	}

	/**
	 * remove unsupported.
	 */
	public void remove()
		throws UnsupportedOperationException, IllegalStateException {
		throw new UnsupportedOperationException();
	}

	/**
	 * The filter for retrieving relevant FOS file names. Names with
	 * deletion or writing suffixes are ignored, as well as non regular files.
	 */
	public boolean accept(File dir, String name) {
		if (name.endsWith(FosObjectFile.WRITESUFFIX))
			return false;
		if (name.endsWith(FosObjectFile.DELETSUFFIX))
			return false;
		File f = new File(dir.getPath() + File.separator + name);
		return f.isFile();
	}
}