/**
 * ObjectWeb Connector: an implementation of JCA Sun specification along
 *                      with some extensions of this specification.
 * Copyright (C) 2001-2002 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 0.1
 *
 * Contact: jorm@objectweb.org
 *
 * Author: S. Chassande-Barrioz, P. Dechamboux
 */

package org.objectweb.perseus.connector.ra;

import java.util.Enumeration;
import java.util.Vector;
import javax.resource.ResourceException;
import javax.resource.cci.Connection;
import javax.resource.cci.ConnectionFactory;
import javax.resource.cci.LocalTransaction;
import javax.resource.spi.ConnectionEvent;
import javax.resource.spi.ConnectionEventListener;
import javax.resource.spi.ConnectionManager;
import javax.resource.spi.ConnectionRequestInfo;
import javax.resource.spi.ManagedConnection;
import javax.resource.spi.ManagedConnectionFactory;

//import org.objectweb.transaction.api.ConnectionManager;
//import org.objectweb.transaction.api.ConnectionFactoryWrapper;

/**
 * The class <b>TestRAMan</b> defines a test suite for testing a correct RA
 * behaviour under managed environment.
 */
public abstract class TestRAMan extends TestRA
	implements ConnectionManager, ConnectionEventListener {

	private boolean isConnectionClosed = false;
	private boolean isConnectionError = false;
	private boolean isLTCommited = false;
	private boolean isLTRollbacked = false;
	private boolean isLTStarted = false;

	private boolean isAllocated = false;

	/**
	 * Constructor in according to the JUnit constraints
	 */
	public TestRAMan(String tn) {
		super(tn);
	}


	//////////////////////////////////////////////////////////////
	// IMPLEMENTATION OF ABSTRACT METHODS INHERITED FROM TestRA //
	//////////////////////////////////////////////////////////////
	/**
	 * This method can be override to initialize the ManagedConnectionFactory.
	 */
	protected void initMCF() throws Exception {
		Object bcf = mcf.createConnectionFactory(
			(javax.resource.spi.ConnectionManager) this);
		/*
		if (bcf instanceof ConnectionFactory)
			cf = (ConnectionFactory) bcf;
		else if (bcf instanceof ConnectionFactoryWrapper)
			cf = ((ConnectionFactoryWrapper) bcf).getCCIConnectionFactory();
		else
			throw new Exception(
				"Cannot obtain a ConnectionFactory from the RA !");
		*/
	}

	/////////////////////////////////////////////////////
	// IMPLEMENTATION OF METHODS OF THE TestCase class //
	/////////////////////////////////////////////////////

	/**
	 * Initialisation sequence executed before each test case.
	 */
	protected void setUp() {
		isConnectionClosed = false;
		isConnectionError = false;
		isLTCommited = false;
		isLTRollbacked = false;
		isLTStarted = false;
		isAllocated = false;
		super.setUp();
	}

	///////////////////////////////////////////////////////
	// IMPLEMENTATION OF THE ConnectionManager INTERFACE //
	///////////////////////////////////////////////////////

	public Object allocateConnection(ManagedConnectionFactory _mcf,
									 ConnectionRequestInfo cri) throws ResourceException {
		isAllocated = true;
		if (mcf != _mcf)
			fail();
		ManagedConnection mc = _mcf.createManagedConnection(null, cri);
		mc.addConnectionEventListener(this);
		Object connection = mc.getConnection(null, cri);
		mc.associateConnection(connection);
		return connection;
	}

	/////////////////////////////////////////////////////////////
	// IMPLEMENTATION OF THE ConnectionEventListener INTERFACE //
	/////////////////////////////////////////////////////////////

	public void connectionClosed(ConnectionEvent event) {
		isConnectionClosed = true;
	}

	public void connectionErrorOccurred(ConnectionEvent event) {
		isConnectionError = true;
	}

	public void localTransactionCommitted(ConnectionEvent event) {
		isLTCommited = true;
	}

	public void localTransactionRolledback(ConnectionEvent event) {
		isLTRollbacked = true;
	}

	public void localTransactionStarted(ConnectionEvent event) {
		isLTStarted = true;
	}


	//////////////////////////////////////////////////////
	// TESTS INTERACTION BETWEEN RA AND ConectionManager//
	//////////////////////////////////////////////////////


	/**
	 * This test checks if during a connection request, the
	 * ConnectionManager is notified
	 */
	public void testNotifyAllocation() {
		try {
			// initialise the test
			isAllocated = false;

			// ask a connection
			Connection c = cf.getConnection();

			// check if getContext was done
			if (!isAllocated)
				fail();

			// End the test
			c.close();
		} catch (Exception e) {
			fail();
		}
	}

	//////////////////////////////////////////////////////////////
	// TESTS INTERACTION BETWEEN RA AND ConnectionEventListener //
	//////////////////////////////////////////////////////////////
	/**
	 * This test checks if during a request on a connection, the
	 * ConnectionEventListener is notified
	 */
	public void testNotifyCloseCEL() {
		try {
			// initialse test
			isConnectionClosed = false;

			// ask a connection
			Connection c = cf.getConnection();

			c.close();

			// check if isConnectionClosed was done
			if (!isConnectionClosed)
				fail();
		} catch (Exception e) {
			fail();
		}
	}

	/**
	 * This test checks if during a request on a connection, the
	 * ConnectionEventListener is notified
	 */
	public void testNotifyLTCommitCEL() {
		try {
			// initialse test
			isLTStarted = false;
			isLTCommited = false;

			// ask a connection
			Connection c = cf.getConnection();
			LocalTransaction lt = c.getLocalTransaction();
			lt.begin();
			if (!isLTStarted)
				fail();
			Enumeration e = writings.elements();
			Writing w = null;
			while (e.hasMoreElements()) {
				w = (Writing) e.nextElement();
				w.init(c);
				w.write(c);
			}
			lt.commit();
			if (!isLTCommited)
				fail();

			// End the test
			c.close();
		} catch (Exception e) {
			fail();
		}
	}

	/**
	 * This test checks if during a request on a connection, the
	 * ConnectionEventListener is notified
	 */
	public void testNotifyLTRollbackCEL() {
		try {
			// initialse test
			isLTStarted = false;
			isLTRollbacked = false;

			// ask a connection
			Connection c = cf.getConnection();
			LocalTransaction lt = c.getLocalTransaction();
			lt.begin();
			if (!isLTStarted)
				fail();
			Enumeration e = writings.elements();
			Writing w = null;
			while (e.hasMoreElements()) {
				w = (Writing) e.nextElement();
				w.init(c);
				w.write(c);
			}
			lt.rollback();
			if (!isLTRollbacked)
				fail();

			// End the test
			c.close();
		} catch (Exception e) {
			fail();
		}
	}
}