/**
 * ObjectWeb Connector: an implementation of JCA Sun specification along
 *                      with some extensions of this specification.
 * Copyright (C) 2001-2002 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 0.1
 *
 * Contact: jorm@objectweb.org
 *
 * Author: S. Chassande-Barrioz, P. Dechamboux
 *
 */

package org.objectweb.perseus.connector.ra;

import javax.resource.cci.Connection;

/**
 * This interface defines a writing test. A test consist to write and read
 * a value from a support. The value can be in only two states: before
 * the writing or after the writing.
 * The test passes if the read function return true in both case
 * - 	read(false) == true
 * - write() ; read(true) == true
 */
public interface Writing {

	void init(Connection c) throws Exception;

	void init() throws Exception;

	/**
	 * Read a data from the support, and check the value. The boolean
	 * parameter is used to check the read value.
	 * The method returns true is the data state is right
	 * The method throws Exceptions if an error occures during the test
	 */
	boolean read(Connection c, boolean isWritten) throws Exception;

	boolean read(boolean isWritten) throws Exception;

	/**
	 *
	 * The method throws Exceptions if an error occures during the test
	 */
	void write(Connection c) throws Exception;

	void write() throws Exception;

	void setConnection(Connection c) throws Exception;
}
