/**
 * ObjectWeb Connector: an implementation of JCA Sun specification along
 *                      with some extensions of this specification.
 * Copyright (C) 2001-2002 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 0.1
 *
 * Contact: jorm@objectweb.org
 *
 * Author: S. Chassande-Barrioz, P. Dechamboux
 *
 */

package org.objectweb.perseus.connector.ra.fos;

import junit.framework.Test;
import junit.framework.TestSuite;
import junit.textui.TestRunner;
import org.objectweb.perseus.LogBoot;
import org.objectweb.perseus.connector.ra.TestRAMan;

import java.util.Properties;
import java.util.Vector;
import javax.resource.spi.ManagedConnectionFactory;

/**
 * The <b>TestRAFileMan</b> class instanciates TestRABasicMan for the File
 * Resource Adapter.
 */
public class TestRAFosMan extends TestRAMan {
	private String dbDir;

	protected Vector getWritings() {
		if (writings == null) {
			writings = new Vector();
			// initialise with a set of tests
			writings.add(new FosWriting(1, "azerty1"));
			writings.add(new FosWriting(2, "azerty2"));
			writings.add(new FosWriting(3, "azerty3"));
		}
		return writings;
	}

	/**
	 * The method implementation must return a new instance of the resource
	 * adapter. The ManagedConnectionFactory is the identifer of the
	 * resource adapter.
	 */
	protected ManagedConnectionFactory getNewMCFInstance()
		throws Exception {
		return (ManagedConnectionFactory) new FosManagedConnectionFactory();
	}

	/**
	 * The method implementation must initialize the resource adapter
	 */
	protected void initMCF() throws Exception {
		((FosManagedConnectionFactory) mcf).setConnectionURL(dbDir);
		((FosManagedConnectionFactory) mcf).setInitializeAtStartUp(true);
		((FosManagedConnectionFactory) mcf).setMonologFactory(LogBoot.getLoggerFactory());
		((FosManagedConnectionFactory) mcf).setConnectionManager(this);
		((FosManagedConnectionFactory) mcf).start();
	}

	protected void endMCF() throws Exception {
		((FosManagedConnectionFactory) mcf).stop();
	}

	/**
	 * Constructs the suite containing all test cases defined within
	 * TestRAMan.
	 */
	public static Test suite() {
		return new TestSuite(TestRAFosMan.class);
	}

	/**
	 * For running the TestRAFileMan suite standalone.
	 */
	public static void main(String args[]) {
		TestRunner.run(suite());
	}

	/**
	 * Constructs a TestRAFileMan.
	 */
	public TestRAFosMan(String tn) {
		super(tn);
		Properties prop = new Properties();
		try {
			prop.load(ClassLoader.getSystemResourceAsStream("owfos.properties"));
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		}
		dbDir = prop.getProperty("dbdir", null);
		if (dbDir == null) {
			System.out.println("Cannot find the 'dbdir' property");
			System.exit(1);
		}
	}
}